==> Task-BeLike-TOBYINK-Utils-2012.150.tar.gz: Task-BeLike-TOBYINK-Utils-2012.150/lib/Task/BeLike/TOBYINK/Utils.pm <==
package Task::BeLike::TOBYINK::Utils;

use 5.010;

BEGIN {
	$Task::BeLike::TOBYINK::Utils::AUTHORITY = 'cpan:TOBYINK';
	$Task::BeLike::TOBYINK::Utils::VERSION   = '2012.150';
}

__PACKAGE__
__END__

=head1 NAME

Task::BeLike::TOBYINK::Utils - be like TOBYINK and use these Utils stuffz

=head1 DESCRIPTION

Task installs the following modules:

=over

=item * Any::Mo

=item * Between

=item * Capture::Attribute

=item * Class::Load

=item * Data::Printer

=item * DateTime

=item * DateTime::Format::ISO8601

=item * DateTimeX::Auto

=item * File::Slurp

=item * Getopt::ArgvFile

=item * Getopt::Long

=item * IO::All

=item * List::MapMulti

=item * List::MoreUtils

=item * List::Pairwise

=item * List::Util

=item * Object::AUTHORITY

=item * Object::DOES

=item * Object::ID

=item * Path::Class

=item * Path::Class::Rule

=item * Scalar::Util

=item * Set::Scalar

=item * Smart::Dispatch

=item * Sort::Key

=item * Test::Exception

=item * Test::More

=item * Test::Warn

=item * Unicode::Debug

=item * namespace::sweep

=item * perl5::tobyink

=item * utf8::all

=back

=head1 SEE ALSO

L<Acme::About::TOBYINK>,
L<Task::BeLike::TOBYINK>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT AND LICENCE

This software is copyright (c) 2012 by Toby Inkster.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 DISCLAIMER OF WARRANTIES

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

==> Task-BeLike-TOBYINK-Utils-2012.276.tar.gz: Task-BeLike-TOBYINK-Utils-2012.276/lib/Task/BeLike/TOBYINK/Utils.pm <==
package Task::BeLike::TOBYINK::Utils;

use 5.010;

BEGIN {
	$Task::BeLike::TOBYINK::Utils::AUTHORITY = 'cpan:TOBYINK';
	$Task::BeLike::TOBYINK::Utils::VERSION   = '2012.276';
}

__PACKAGE__
__END__

=head1 NAME

Task::BeLike::TOBYINK::Utils - be like TOBYINK and use these Utils stuffz

=head1 DESCRIPTION

Task installs the following modules:

=over

=item * Any::Mo

=item * Between

=item * Capture::Attribute

=item * Class::Load

=item * Data::Printer

=item * DateTime

=item * DateTime::Format::ISO8601

=item * DateTimeX::Auto

=item * File::Slurp

=item * Getopt::ArgvFile

=item * Getopt::Long

=item * IO::All

=item * List::MapMulti

=item * List::MoreUtils

=item * List::Pairwise

=item * List::Util

=item * Object::AUTHORITY

=item * Object::DOES

=item * Object::ID

=item * Path::Class

=item * Path::Class::Rule

=item * PerlX::MethodCallWithBlock

=item * Scalar::Does

=item * Scalar::Util

=item * Set::Scalar

=item * Smart::Dispatch

=item * Sort::Key

=item * Syntax::Collector

=item * Test::Exception

=item * Test::More

=item * Test::Warn

=item * Unicode::Debug

=item * aliased

=item * namespace::sweep

=item * utf8::all

=back

=head1 SEE ALSO

L<Acme::About::TOBYINK>,
L<Task::BeLike::TOBYINK>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT AND LICENCE

This software is copyright (c) 2012 by Toby Inkster.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 DISCLAIMER OF WARRANTIES

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
